==> hboard-1.0.2b.tar.gz: hboard/post_article.php <==
<?php

/* EtchiBoard Version 1.0
     post_article.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); // /ϴܺ
include ("lib/message.inc"); // ޽ function

/* ʼ ˻ !
    ũ,  Է¿  ⼭  ݴϴ. */

//  ó: ^^+
$name = str_replace("", " ", $name);
$name = trim($name);
$title = str_replace("", " ", $title);
$title = trim($title);
$homepage = str_replace("", " ", $homepage);
$homepage = trim($homepage);
$email = str_replace("", " ", $email);
$email = trim($email);

/* ׸ ũⰡ ڰ  ũ⺸ Ŭ  (0  ǹ̹Ƿ ..) */
if($admin_data[fileup_max] != "0" && $picture_size > $admin_data[fileup_max]) {
 $fileup_max_in_kb = (int)(($admin_data[fileup_max]/1024+0.5));
 PrintHeader();
 PrintMessage("<b> ũⰡ ʹ Ůϴ!</b><br>  ũ ִ ${fileup_max_in_kb}KB ѵ˴ϴ.", "error");
 PrintFooter();
}

/* ̸, ׸, йȣ ϵ ʾ .. */
else if($name == "" || $picture == "" || $passwd == "" || $ne == "") {
 PrintHeader();
 PrintMessage("<b>Ͱ  ۵ ʾҽϴ.</b><br> ʿ  ͸  äּ.", "error");
 PrintFooter();
}

/*  ̶.. */
else {

 // Ű 
 setcookie("hboard10_name", $name, time() + 2592000);
 setcookie("hboard10_email", $email, time() + 2592000);
 setcookie("hboard10_homepage", $homepage, time() + 2592000);

 PrintHeader();

if($homepage == "http://") $homepage = ""; // http://  ׳ Ȩ 

$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);
 // Խ db ī б
 $result = mysql_fetch_array(mysql_query("select count(*) from hboard_db_article", $dbconnect));
 $article_no = ($result[0] + 1);


 /* ׸ óκ #1 */

  //  ߺ üũ: v1.0.1 ~
  $picture_md5 = md5_file($picture); // ϴ ׸ md5 ߿ .. 

  if($admin_data[backdrum] == "t") {
   $result = mysql_fetch_array(mysql_query("select count(*) from hboard_db_article where md5='${picture_md5}' and deleted='f'", $dbconnect));

   if($result[0] != "0") { //  ߔ̸
    $result = mysql_query("select * from hboard_db_article where md5='${picture_md5}' and deleted='f'", $dbconnect);
    $backdrum[idx] = mysql_result($result, 0, "idx"); // idx
    $backdrum[cfile] = mysql_result($result, 0, "cfile"); // idx

	PrintMessage("<b>${backdrum[idx]} ۿ   ߰ߵǾϴ.</b><br>\n<a href=\"search.php?search_word=${backdrum[cfile]}&amp;search_type=cfile#${backdrum[idx]}\" target=\"_blank\">[⸦ ŬϽø ${backdrum[idx]}  Ȯմϴ. (˻)]</a><br>", "error"); // ߺ ߻

	unlink($picture);
    die; // ׾ -_-
   }
  }

  // ($pic_bodynumber Խù ȣ 1 00001  ޴ )
  if($article_no <= 9) $pic_bodynumber = "00000" .$article_no;
  else if($article_no <= 99) $pic_bodynumber = "0000" .$article_no;
  else if($article_no <= 999) $pic_bodynumber = "000" .$article_no;
  else if($article_no <= 9999) $pic_bodynumber = "00" .$article_no;
  else if($article_no <= 99999) $pic_bodynumber = "0" .$article_no;
  else $pic_bodynumber = $article_no;

  // ׸ϸ .. (Ȯڴ type ..Ѥ)
  if($picture_type == "image/gif") { $pic_filename = date('Y_m_d') ."_" .$pic_bodynumber .".gif"; }
  else if($picture_type == "image/pjpeg" || $picture_type == "image/jpeg") { $pic_filename = date('Y_m_d') ."_" .$pic_bodynumber .".jpg"; }
  else if($picture_type == "image/x-png" || $picture_type == "image/png") { $pic_filename = date('Y_m_d') ."_" .$pic_bodynumber .".png"; }
  else if($picture_type == "image/bmp") { $pic_filename = date('Y_m_d') ."_" .$pic_bodynumber .".bmp"; }
  else { $pic_filename = date('Y_m_d') ."_" .$pic_bodynumber .".unknown"; }

 // user agent, ipּ ޱ
 $user_agent = $_SERVER["HTTP_USER_AGENT"];
 $ip_addr = $_SERVER["REMOTE_ADDR"];

 // db ó
 $passwd = crypt($passwd, HB);
 $now_date = date("Y/m/d H:i:s");

 mysql_query("insert into hboard_db_article values(\"$article_no\", \"$name\", \"$email\", \"$homepage\", \"$ip_addr\", \"$passwd\", \"$now_date\", \"$pic_filename\", \"$title\", \"$ne\", \"f\", \"0\", \"$user_agent\", \"$picture_md5\")");

 /* ׸ óκ #2 */

  // ε  ó(ũ/)κ..
  copy($picture,"db/img/" .$pic_filename);
  chmod("db/img/" .$pic_filename, 0777);
  unlink($picture);

 // ̹ db  뷮 ߰ϱ
  $file_open = file("db/img/dbinfo");
   $db_size = trim($file_open[1]);
   $db_size = ($db_size + $picture_size);
  $file_open = fopen("db/img/dbinfo", "w");
   fwrite($file_open, "[size]\n${db_size}");
   fclose($file_open);

 // ޽  ( ܰ)
  PrintMessage("Խù  Ϸ߽ϴ.", "notice");
  mysql_close($dbconnect);

 PrintFooter();

}
?>

==> hboard-1.0.3.tar.gz: hboard/post_article.php <==
<?php

/* EtchiBoard Version 1.0
     post_article.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("lib/headfoot.inc"); // /ϴܺ
include ("lib/message.inc"); // ޽ function

/* ʼ ˻ !
    ũ,  Է¿  ⼭  ݴϴ. */

//  ó: ^^+
$name = str_replace("", " ", $name);
$name = trim($name);
$title = str_replace("", " ", $title);
$title = trim($title);
$homepage = str_replace("", " ", $homepage);
$homepage = trim($homepage);
$email = str_replace("", " ", $email);
$email = trim($email);

/* ׸ ũⰡ ڰ  ũ⺸ Ŭ  (0  ǹ̹Ƿ ..) */
if($admin_data[fileup_max] != "0" && $picture_size > $admin_data[fileup_max]) {
 $fileup_max_in_kb = (int)(($admin_data[fileup_max]/1024+0.5));
 PrintHeader();
 PrintMessage("<b> ũⰡ ʹ Ůϴ!</b><br>  ũ ִ ${fileup_max_in_kb}KB ѵ˴ϴ.", "error");
 PrintFooter();
}

/* ̸, ׸, йȣ ϵ ʾ .. */
else if($name == "" || $picture == "" || $passwd == "" || $ne == "") {
 PrintHeader();
 PrintMessage("<b>Ͱ  ۵ ʾҽϴ.</b><br> ʿ  ͸  äּ.", "error");
 PrintFooter();
}

/*  ̶.. */
else {

 // Ű 
 setcookie("hboard10_name", $name, time() + 2592000);
 setcookie("hboard10_email", $email, time() + 2592000);
 setcookie("hboard10_homepage", $homepage, time() + 2592000);

 PrintHeader();

if($homepage == "http://") $homepage = ""; // http://  ׳ Ȩ 

$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);
 // Խ db ī б
 $result = mysql_fetch_array(mysql_query("select count(*) from hboard_db_article", $dbconnect));
 $article_no = ($result[0] + 1);


 /* ׸ óκ #1 */

// PHP  üũ,   4.2.x ̶̻ md5 DB ..
$php_version = phpversion();
if($php_version) $php_version_head = substr($php_version, 0, 3);

if($php_version > 4.2) {
 $picture_md5 = md5_file($picture);
}
else {
 $picture_md5 = "NO_MD5";
}

  //  ߺ üũ: v1.0.1 ~
   if($admin_data[backdrum] == "t") {

	$result = mysql_fetch_array(mysql_query("select count(*) from hboard_db_article where md5='${picture_md5}' and deleted='f'", $dbconnect));

   if($result[0] != "0") { //  ߔ̸
    $result = mysql_query("select * from hboard_db_article where md5='${picture_md5}' and deleted='f'", $dbconnect);
    $backdrum[idx] = mysql_result($result, 0, "idx"); // idx
    $backdrum[cfile] = mysql_result($result, 0, "cfile"); // idx

	PrintMessage("<b>${backdrum[idx]} ۿ   ߰ߵǾϴ.</b><br>\n<a href=\"search.php?search_word=${backdrum[cfile]}&amp;search_type=cfile#${backdrum[idx]}\" target=\"_blank\">[⸦ ŬϽø ${backdrum[idx]}  Ȯմϴ. (˻)]</a><br>", "error"); // ߺ ߻

	unlink($picture);
    die; // ׾ -_-
   }
  }

  // ($pic_bodynumber Խù ȣ 1 00001  ޴ )
  if($article_no <= 9) $pic_bodynumber = "00000" .$article_no;
  else if($article_no <= 99) $pic_bodynumber = "0000" .$article_no;
  else if($article_no <= 999) $pic_bodynumber = "000" .$article_no;
  else if($article_no <= 9999) $pic_bodynumber = "00" .$article_no;
  else if($article_no <= 99999) $pic_bodynumber = "0" .$article_no;
  else $pic_bodynumber = $article_no;

  // ׸ϸ .. (Ȯڴ type ..Ѥ)
  if($picture_type == "image/gif") { $pic_filename = date('Y_m_d') ."_" .$pic_bodynumber .".gif"; }
  else if($picture_type == "image/pjpeg" || $picture_type == "image/jpeg") { $pic_filename = date('Y_m_d') ."_" .$pic_bodynumber .".jpg"; }
  else if($picture_type == "image/x-png" || $picture_type == "image/png") { $pic_filename = date('Y_m_d') ."_" .$pic_bodynumber .".png"; }
  else if($picture_type == "image/bmp") { $pic_filename = date('Y_m_d') ."_" .$pic_bodynumber .".bmp"; }
  else { $pic_filename = date('Y_m_d') ."_" .$pic_bodynumber .".unknown"; }

 // user agent, ipּ ޱ
 $user_agent = $_SERVER["HTTP_USER_AGENT"];
 $ip_addr = $_SERVER["REMOTE_ADDR"];

 // db ó
 $passwd = crypt($passwd, HB);
 $now_date = date("Y/m/d H:i:s");

 mysql_query("insert into hboard_db_article values(\"$article_no\", \"$name\", \"$email\", \"$homepage\", \"$ip_addr\", \"$passwd\", \"$now_date\", \"$pic_filename\", \"$title\", \"$ne\", \"f\", \"0\", \"$user_agent\", \"$picture_md5\")");

 /* ׸ óκ #2 */

  // ε  ó(ũ/)κ..
  copy($picture,"db/img/" .$pic_filename);
  chmod("db/img/" .$pic_filename, 0777);
  unlink($picture);

 // ̹ db  뷮 ߰ϱ
  $file_open = file("db/img/dbinfo");
   $db_size = trim($file_open[1]);
   $db_size = ($db_size + $picture_size);
  $file_open = fopen("db/img/dbinfo", "w");
   fwrite($file_open, "[size]\n${db_size}");
   fclose($file_open);

 // ޽  ( ܰ)
  PrintMessage("Խù  Ϸ߽ϴ.", "notice");
  mysql_close($dbconnect);

 PrintFooter();

}
?>
